@@ -3,7 +3,7 @@
 #
 # furl - URL manipulation made simple.
 #
-# Arthur Grunseid
+# Ansgar Grunseid
 # grunseid.com
 # grunseid@gmail.com
 #
@@ -13,8 +13,8 @@
 from .furl import *
 
 __title__ = 'furl'
-__version__ = '1.0.1'
+__version__ = '1.1'
 __license__ = 'Unlicense'
-__author__ = 'Arthur Grunseid'
+__author__ = 'Ansgar Grunseid'
 __contact__ = 'grunseid@gmail.com'
 __url__ = 'https://github.com/gruns/furl'
