@@ -3,7 +3,7 @@
 #
 # furl - URL manipulation made simple.
 #
-# Arthur Grunseid
+# Ansgar Grunseid
 # grunseid.com
 # grunseid@gmail.com
 #
@@ -12,11 +12,13 @@
 
 import sys
 
+
 if sys.version_info[0] == 2:
     basestring = basestring
 else:
     basestring = (str, bytes)
 
+
 if list(sys.version_info[:2]) >= [2, 7]:
     from collections import OrderedDict
 else:
@@ -25,8 +27,8 @@ else:
 
 class UnicodeMixin(object):
     """
-    Mixin class to handle defining the proper __str__/__unicode__ methods in
-    Python 2 or 3.
+    Mixin class to handle defining the proper __str__/__unicode__
+    methods in Python 2 or 3.
     """
     if sys.version_info[0] >= 3:  # Python 3
         def __str__(self):
